==> cogl-1.16.2.tgz: include/cogl/cogl/cogl-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __COGL_ENUM_TYPES_H__
#define __COGL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./cogl-bitmap.h" */
GType cogl_bitmap_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BITMAP_ERROR (cogl_bitmap_error_get_type())

/* enumerations from "./cogl-material-compat.h" */
GType cogl_material_filter_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_FILTER (cogl_material_filter_get_type())

GType cogl_material_wrap_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_WRAP_MODE (cogl_material_wrap_mode_get_type())

GType cogl_material_alpha_func_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_ALPHA_FUNC (cogl_material_alpha_func_get_type())

GType cogl_material_layer_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_LAYER_TYPE (cogl_material_layer_type_get_type())

/* enumerations from "./cogl-shader.h" */
GType cogl_shader_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_SHADER_TYPE (cogl_shader_type_get_type())

/* enumerations from "./cogl-texture.h" */
GType cogl_texture_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_ERROR (cogl_texture_error_get_type())

GType cogl_texture_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_TYPE (cogl_texture_type_get_type())

/* enumerations from "./cogl-types.h" */
GType cogl_pixel_format_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_PIXEL_FORMAT (cogl_pixel_format_get_type())

GType cogl_feature_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FEATURE_FLAGS (cogl_feature_flags_get_type())

GType cogl_buffer_target_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_TARGET (cogl_buffer_target_get_type())

GType cogl_texture_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_FLAGS (cogl_texture_flags_get_type())

GType cogl_fog_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FOG_MODE (cogl_fog_mode_get_type())

GType cogl_blend_string_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BLEND_STRING_ERROR (cogl_blend_string_error_get_type())

GType cogl_system_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_SYSTEM_ERROR (cogl_system_error_get_type())

GType cogl_attribute_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_ATTRIBUTE_TYPE (cogl_attribute_type_get_type())

GType cogl_indices_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_INDICES_TYPE (cogl_indices_type_get_type())

GType cogl_vertices_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_VERTICES_MODE (cogl_vertices_mode_get_type())

GType cogl_depth_test_function_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_DEPTH_TEST_FUNCTION (cogl_depth_test_function_get_type())

GType cogl_renderer_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_RENDERER_ERROR (cogl_renderer_error_get_type())

GType cogl_winsys_feature_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_WINSYS_FEATURE (cogl_winsys_feature_get_type())

GType cogl_color_mask_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_COLOR_MASK (cogl_color_mask_get_type())

GType cogl_winding_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_WINDING (cogl_winding_get_type())

GType cogl_buffer_bit_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_BIT (cogl_buffer_bit_get_type())

GType cogl_read_pixels_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_READ_PIXELS_FLAGS (cogl_read_pixels_flags_get_type())

G_END_DECLS

#endif /* __COGL_ENUM_TYPES_H__ */

/* Generated data ends here */

==> cogl-1.22.2p1.tgz: include/cogl/cogl/cogl-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __COGL_ENUM_TYPES_H__
#define __COGL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./cogl-bitmap.h" */
GType cogl_bitmap_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BITMAP_ERROR (cogl_bitmap_error_get_type())

/* enumerations from "./cogl-texture.h" */
GType cogl_texture_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_ERROR (cogl_texture_error_get_type())

GType cogl_texture_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_TYPE (cogl_texture_type_get_type())

GType cogl_texture_components_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_COMPONENTS (cogl_texture_components_get_type())

/* enumerations from "./cogl-types.h" */
GType cogl_pixel_format_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_PIXEL_FORMAT (cogl_pixel_format_get_type())

GType cogl_feature_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FEATURE_FLAGS (cogl_feature_flags_get_type())

GType cogl_buffer_target_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_TARGET (cogl_buffer_target_get_type())

GType cogl_texture_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_FLAGS (cogl_texture_flags_get_type())

GType cogl_fog_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FOG_MODE (cogl_fog_mode_get_type())

GType cogl_blend_string_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BLEND_STRING_ERROR (cogl_blend_string_error_get_type())

GType cogl_system_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_SYSTEM_ERROR (cogl_system_error_get_type())

GType cogl_attribute_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_ATTRIBUTE_TYPE (cogl_attribute_type_get_type())

GType cogl_indices_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_INDICES_TYPE (cogl_indices_type_get_type())

GType cogl_vertices_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_VERTICES_MODE (cogl_vertices_mode_get_type())

GType cogl_depth_test_function_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_DEPTH_TEST_FUNCTION (cogl_depth_test_function_get_type())

GType cogl_renderer_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_RENDERER_ERROR (cogl_renderer_error_get_type())

GType cogl_winsys_feature_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_WINSYS_FEATURE (cogl_winsys_feature_get_type())

GType cogl_color_mask_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_COLOR_MASK (cogl_color_mask_get_type())

GType cogl_winding_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_WINDING (cogl_winding_get_type())

GType cogl_buffer_bit_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_BIT (cogl_buffer_bit_get_type())

GType cogl_read_pixels_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_READ_PIXELS_FLAGS (cogl_read_pixels_flags_get_type())

GType cogl_stereo_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_STEREO_MODE (cogl_stereo_mode_get_type())

/* enumerations from "./deprecated/cogl-material-compat.h" */
GType cogl_material_filter_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_FILTER (cogl_material_filter_get_type())

GType cogl_material_wrap_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_WRAP_MODE (cogl_material_wrap_mode_get_type())

GType cogl_material_alpha_func_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_ALPHA_FUNC (cogl_material_alpha_func_get_type())

GType cogl_material_layer_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_LAYER_TYPE (cogl_material_layer_type_get_type())

/* enumerations from "./deprecated/cogl-shader.h" */
GType cogl_shader_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_SHADER_TYPE (cogl_shader_type_get_type())

G_END_DECLS

#endif /* __COGL_ENUM_TYPES_H__ */

/* Generated data ends here */
